@@ -1,3 +1,4 @@
+import os
 import re
 
 from colorama import init, Fore, Style
@@ -18,9 +19,11 @@ class Record:
     file_line_range = []
     resource = ""
     guideline = None
+    fixed_definition = None
+    entity_tags = None
 
     def __init__(self, check_id, check_name, check_result, code_block, file_path, file_line_range, resource,
-                 evaluations, check_class):
+                 evaluations, check_class, file_abs_path, entity_tags=None):
         """
         :param evaluations: A dict with the key being the variable name, value being a dict containing:
                              - 'var_file'
@@ -32,10 +35,13 @@ class Record:
         self.check_result = check_result
         self.code_block = code_block
         self.file_path = file_path
+        self.repo_file_path = f'/{os.path.relpath(file_abs_path)}' # matches file paths given in the BC platform.
         self.file_line_range = file_line_range
         self.resource = resource
         self.evaluations = evaluations
         self.check_class = check_class
+        self.fixed_definition = None
+        self.entity_tags = entity_tags
 
     def set_guideline(self, guideline):
         self.guideline = guideline
@@ -61,7 +67,7 @@ class Record:
                 string_block += "\t\t" + Fore.WHITE + str(line_num) + spaces + ' | ' + Fore.YELLOW + line
         return string_block
 
-    def __str__(self):
+    def to_string(self, compact=False):
         status = ''
         evaluation_message = f''
         status_color = "white"
@@ -99,10 +105,13 @@ class Record:
                             f'in expression: {colored(definition_obj["definition_name"] + " = ", "yellow")}{colored(definition_obj["definition_expression"], "yellow")}\n',
                             'white')
         status_message = colored("\t{} for resource: {}\n".format(status, self.resource), status_color)
-        if self.check_result['result'] == CheckResult.FAILED and code_lines:
+        if self.check_result['result'] == CheckResult.FAILED and code_lines and not compact:
             return check_message + status_message + file_details + guideline_message + code_lines + evaluation_message
 
         if self.check_result['result'] == CheckResult.SKIPPED:
             return check_message + status_message + suppress_comment + file_details + guideline_message
         else:
             return check_message + status_message + file_details + evaluation_message + guideline_message
+
+    def __str__(self):
+        return self.to_string()
