@@ -19,15 +19,15 @@ class Report:
         self.passed_checks = []
         self.failed_checks = []
         self.skipped_checks = []
-        self.parsing_errors = {}
+        self.parsing_errors = []
 
     def add_parsing_errors(self, errors):
         for file in errors:
-            self.add_parsing_error(file, errors[file])
+            self.add_parsing_error(file)
 
-    def add_parsing_error(self, file, error):
-        if file and error:
-            self.parsing_errors[file] = str(error)
+    def add_parsing_error(self, file):
+        if file:
+            self.parsing_errors.append(file)
 
     def add_record(self, record):
         if record.check_result['result'] == CheckResult.PASSED:
@@ -49,17 +49,26 @@ class Report:
     def get_json(self):
         return json.dumps(self.get_dict(), indent=4)
 
-    def get_dict(self):
-        return {
-            "check_type": self.check_type,
-            "results": {
-                "passed_checks": [check.__dict__ for check in self.passed_checks],
-                "failed_checks": [check.__dict__ for check in self.failed_checks],
-                "skipped_checks": [check.__dict__ for check in self.skipped_checks],
-                "parsing_errors": self.parsing_errors
-            },
-            "summary": self.get_summary()
+    def get_dict(self, is_quiet=False):
+        if is_quiet:
+            return {
+                "check_type": self.check_type,
+                "results": {
+                    "failed_checks": [check.__dict__ for check in self.failed_checks]
+                },
+                "summary": self.get_summary()
         }
+        else: 
+            return {
+                "check_type": self.check_type,
+                "results": {
+                    "passed_checks": [check.__dict__ for check in self.passed_checks],
+                    "failed_checks": [check.__dict__ for check in self.failed_checks],
+                    "skipped_checks": [check.__dict__ for check in self.skipped_checks],
+                    "parsing_errors": list(self.parsing_errors)
+                },
+                "summary": self.get_summary()
+            }
 
     def get_exit_code(self, soft_fail):
         if soft_fail:
@@ -71,7 +80,7 @@ class Report:
     def is_empty(self):
         return len(self.passed_checks) + len(self.failed_checks) + len(self.skipped_checks) + len(self.parsing_errors) == 0
 
-    def print_console(self, is_quiet=False):
+    def print_console(self, is_quiet=False, is_compact=False):
         summary = self.get_summary()
         print(colored(f"{self.check_type} scan results:", "blue"))
         if self.parsing_errors:
@@ -83,20 +92,20 @@ class Report:
         print(colored(message, "cyan"))
         if not is_quiet:
             for record in self.passed_checks:
-                print(record)
+                print(record.to_string(compact=is_compact))
         for record in self.failed_checks:
-            print(record)
+            print(record.to_string(compact=is_compact))
         if not is_quiet:
             for record in self.skipped_checks:
-                print(record)
+                print(record.to_string(compact=is_compact))
 
         if not is_quiet:
-            for file, error in self.parsing_errors.items():
-                Report._print_parsing_error_console(file, error)
+            for file in self.parsing_errors:
+                Report._print_parsing_error_console(file)
 
     @staticmethod
-    def _print_parsing_error_console(file, error):
-        print(colored(f'Error parsing file {file}: {error}', 'red'))
+    def _print_parsing_error_console(file):
+        print(colored(f'Error parsing file {file}', 'red'))
 
     def print_junit_xml(self):
         ts = self.get_test_suites()
