@@ -2,6 +2,7 @@ import json
 import logging
 from abc import abstractmethod
 
+from checkov.common.bridgecrew.integration_features.integration_feature_registry import integration_feature_registry
 from checkov.common.output.report import Report
 
 OUTPUT_CHOICES = ['cli', 'json', 'junitxml', 'github_failed_only']
@@ -27,16 +28,18 @@ class RunnerRegistry(object):
     def extract_entity_details(self, entity):
         raise NotImplementedError()
 
-    def run(self, root_folder=None, external_checks_dir=None, files=None, guidelines=None, collect_skip_comments=True):
+    def run(self, root_folder=None, external_checks_dir=None, files=None, guidelines=None, collect_skip_comments=True, bc_integration=None):
         for runner in self.runners:
+            integration_feature_registry.run_pre_scan()
             scan_report = runner.run(root_folder, external_checks_dir=external_checks_dir, files=files,
                                      runner_filter=self.runner_filter, collect_skip_comments=collect_skip_comments)
+            integration_feature_registry.run_post_scan(scan_report)
             if guidelines:
                 RunnerRegistry.enrich_report_with_guidelines(scan_report, guidelines)
             self.scan_reports.append(scan_report)
         return self.scan_reports
 
-    def print_reports(self, scan_reports, args):
+    def print_reports(self, scan_reports, args, url=None):
         if args.output == 'cli':
             print(f"{self.banner}\n")
         exit_codes = []
@@ -45,14 +48,16 @@ class RunnerRegistry(object):
         for report in scan_reports:
             if not report.is_empty():
                 if args.output == "json":
-                    report_jsons.append(report.get_dict())
+                    report_jsons.append(report.get_dict(is_quiet=args.quiet))
                 elif args.output == "junitxml":
                     junit_reports.append(report)
                     # report.print_junit_xml()
                 elif args.output == 'github_failed_only':
                     report.print_failed_github_md()
                 else:
-                    report.print_console(is_quiet=args.quiet)
+                    report.print_console(is_quiet=args.quiet, is_compact=args.compact)
+                    if url:
+                        print("More details: {}".format(url))
             exit_codes.append(report.get_exit_code(args.soft_fail))
         if args.output == "junitxml":
             if len(junit_reports) == 1:
