@@ -14,7 +14,7 @@ class MinimizeCapabilities(BaseK8Check):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
     def get_resource_id(self, conf):
-        return conf['parent']
+        return f'{conf["parent"]} - {conf["name"]}'
 
     def scan_spec_conf(self, conf):
         if "securityContext" in conf:
@@ -25,4 +25,5 @@ class MinimizeCapabilities(BaseK8Check):
                             return CheckResult.PASSED
         return CheckResult.FAILED
 
-check = MinimizeCapabilities()
\ No newline at end of file
+
+check = MinimizeCapabilities()
