@@ -22,10 +22,11 @@ class SeccompPSP(BaseK8Check):
     def scan_spec_conf(self, conf):
         if "metadata" in conf:
             if "annotations" in conf["metadata"]:
-                if "seccomp.security.alpha.kubernetes.io/defaultProfileName" in conf["metadata"]["annotations"]:
-                    if ("docker/default" in conf["metadata"]["annotations"]["seccomp.security.alpha.kubernetes.io/defaultProfileName"] or
-                        "runtime/default" in conf["metadata"]["annotations"]["seccomp.security.alpha.kubernetes.io/defaultProfileName"]):
-                        return CheckResult.PASSED
+                for annotation in conf["metadata"]["annotations"]:
+                    for key in annotation:
+                        if "seccomp.security.alpha.kubernetes.io/defaultProfileName" in key:
+                            if "docker/default" in annotation[key] or "runtime/default" in annotation[key]:
+                                return CheckResult.PASSED
         return CheckResult.FAILED
 
 
