@@ -2,7 +2,7 @@ import logging
 import operator
 import os
 from functools import reduce
-
+from checkov.common.util.type_forcers import force_list
 from checkov.common.output.record import Record
 from checkov.common.output.report import Report
 from checkov.common.runners.base_runner import BaseRunner, filter_ignored_directories
@@ -51,6 +51,18 @@ class Runner(BaseRunner):
                     (definitions[relative_file_path], definitions_raw[relative_file_path]) = parse_result
 
         for k8_file in definitions.keys():
+
+            # There are a few cases here. If -f was used, there could be a leading / because it's an absolute path,
+            # or there will be no leading slash; root_folder will always be none.
+            # If -d is used, root_folder will be the value given, and -f will start with a / (hardcoded above).
+            # The goal here is simply to get a valid path to the file (which sls_file does not always give).
+            if k8_file[0] == '/':
+                path_to_convert = (root_folder + k8_file) if root_folder else k8_file
+            else:
+                path_to_convert = (os.path.join(root_folder, k8_file)) if root_folder else k8_file
+
+            file_abs_path = os.path.abspath(path_to_convert)
+
             if definitions[k8_file]:
                 for i in range(len(definitions[k8_file])):
                     if (not 'apiVersion' in definitions[k8_file][i].keys()) and (not 'kind' in definitions[k8_file][i].keys()):
@@ -170,7 +182,7 @@ class Runner(BaseRunner):
                                         code_block=entity_code_lines, file_path=k8_file,
                                         file_line_range=entity_lines_range,
                                         resource=check.get_resource_id(entity_conf), evaluations=variable_evaluations,
-                                        check_class=check.__class__.__module__)
+                                        check_class=check.__class__.__module__, file_abs_path=file_abs_path)
                         report.add_record(record=record)
 
         return report
@@ -216,19 +228,25 @@ def get_skipped_checks(entity_conf):
         if "metadata" in entity_conf.keys():
             metadata = entity_conf["metadata"]
     if "annotations" in metadata.keys() and metadata["annotations"] is not None:
-        for key in metadata["annotations"].keys():
-            skipped_item = {}
-            if "checkov.io/skip" in key or "bridgecrew.io/skip" in key:
-                if "CKV_K8S" in metadata["annotations"][key]:
-                    if "=" in metadata["annotations"][key]:
-                        (skipped_item["id"], skipped_item["suppress_comment"]) = metadata["annotations"][key].split("=")
+        if isinstance(metadata["annotations"], dict):
+            metadata["annotations"] = force_list(metadata["annotations"])
+        for annotation in metadata["annotations"]:
+            if not isinstance(annotation, dict):
+                logging.debug( f"Parse of Annotation Failed for {annotation}: {entity_conf}")
+                continue
+            for key in annotation:
+                skipped_item = {}
+                if "checkov.io/skip" in key or "bridgecrew.io/skip" in key:
+                    if "CKV_K8S" in annotation[key]:
+                        if "=" in annotation[key]:
+                            (skipped_item["id"], skipped_item["suppress_comment"]) = annotation[key].split("=")
+                        else:
+                            skipped_item["id"] = annotation[key]
+                            skipped_item["suppress_comment"] = "No comment provided"
+                        skipped.append(skipped_item)
                     else:
-                        skipped_item["id"] = metadata["annotations"][key]
-                        skipped_item["suppress_comment"] = "No comment provided"
-                    skipped.append(skipped_item)
-                else:
-                    logging.debug("Parse of Annotation Failed for {}: {}".format(metadata["annotations"][key], entity_conf, indent=2))
-                    continue
+                        logging.debug("Parse of Annotation Failed for {}: {}".format(metadata["annotations"][key], entity_conf, indent=2))
+                        continue
     return skipped
 
 def _get_from_dict(data_dict, map_list):
