@@ -17,15 +17,19 @@ class EKSPublicAccessCIDR(BaseResourceCheck):
         :param conf: aws_eks_cluster configuration
         :return: <CheckResult>
         """
+        self.evaluated_keys = 'vpc_config'
         if "vpc_config" in conf.keys():
             if "endpoint_public_access" in conf["vpc_config"][0].keys() and not conf["vpc_config"][0]["endpoint_public_access"][0]:
+                self.evaluated_keys = 'vpc_config/[0]/endpoint_public_access'
                 return CheckResult.PASSED
             elif "public_access_cidrs" in conf["vpc_config"][0].keys():
-                if not len(conf["vpc_config"][0]["public_access_cidrs"][0]) or "0.0.0.0/0" in conf["vpc_config"][0]["public_access_cidrs"][0]:
+                self.evaluated_keys = 'vpc_config/[0]/public_access_cidrs'
+                if not len(conf["vpc_config"][0]["public_access_cidrs"][0]) or "0.0.0.0/0" in conf["vpc_config"][0]["public_access_cidrs"][0]:  # nosec
                     return CheckResult.FAILED
                 else:
                     return CheckResult.PASSED
             else:
+                self.evaluated_keys = 'vpc_config'
                 return CheckResult.FAILED
         else:
             return CheckResult.UNKNOWN
