@@ -7,7 +7,7 @@ from checkov.common.util.type_forcers import force_list
 class LambdaEnvironmentCredentials(BaseResourceCheck):
 
     def __init__(self):
-        name = "Ensure no hard coded AWS access key and secret key exists in lambda environment"
+        name = "Ensure no hard-coded secrets exists in lambda environment"
         id = "CKV_AWS_45"
         supported_resources = ['aws_lambda_function']
         categories = [CheckCategories.SECRETS]
@@ -15,7 +15,7 @@ class LambdaEnvironmentCredentials(BaseResourceCheck):
 
     def scan_resource_conf(self, conf):
         self.evaluated_keys = 'environment/[0]/variables'
-        if 'environment' in conf.keys():
+        if len(conf.get('environment', [])) > 0:
             if isinstance(conf['environment'][0], dict):
                 if 'variables' in conf['environment'][0]:
                     if isinstance(force_list(conf['environment'][0]['variables'])[0], dict):
