@@ -4,11 +4,10 @@ import os
 import re
 from pathlib import Path
 from typing import Mapping, Optional, Dict, Any, List, Callable, Tuple
-
+import copy
 import deep_merge
 import hcl2
 import jmespath
-from dataclasses import dataclass
 
 from checkov.common.runners.base_runner import filter_ignored_directories
 from checkov.common.util.consts import DEFAULT_EXTERNAL_MODULES_DIR, RESOLVED_MODULE_ENTRY_NAME
@@ -16,7 +15,7 @@ from checkov.common.util.type_forcers import convert_str_to_bool
 from checkov.common.variables.context import EvaluationContext, VarReference
 from checkov.terraform.module_loading.registry import ModuleLoaderRegistry
 from checkov.terraform.module_loading.registry import module_loader_registry as default_ml_registry
-
+from checkov.terraform.parser_var_blocks import find_var_blocks, split_merge_args
 
 LOGGER = logging.getLogger(__name__)
 
@@ -169,7 +168,7 @@ class Parser:
                 continue
 
             # Resource files
-            if file.name.endswith(".tf.json") or file.name.endswith(".tf"):
+            if file.name.endswith(".tf"):  # TODO: add support for .tf.json
                 data = _load_or_die_quietly(file, self.out_parsing_errors)
             else:
                 continue
@@ -210,9 +209,10 @@ class Parser:
                 continue
             var_value_and_file_map[key[7:]] = value, f"env:{key}"
         if hcl_tfvars:                                                      # terraform.tfvars
-            data = _load_or_die_quietly(hcl_tfvars, self.out_parsing_errors)
+            data = _load_or_die_quietly(hcl_tfvars, self.out_parsing_errors,
+                                        clean_definitions=False)
             if data:
-                var_value_and_file_map.update({k: (v, hcl_tfvars.path) for k, v in data.items()})
+                var_value_and_file_map.update({k: (_safe_index(v, 0), hcl_tfvars.path) for k, v in data.items()})
         if json_tfvars:                                                     # terraform.tfvars.json
             data = _load_or_die_quietly(json_tfvars, self.out_parsing_errors)
             if data:
@@ -310,9 +310,28 @@ class Parser:
                 if isinstance(value, str):
                     altered_value = value
 
-                    had_pattern_match = False
+                    had_var_block_match = False
+
+                    # The way in which matches are processed is important as they are ordered and may contain
+                    # portions of one another. For example:
+                    #  ${merge(local.common_tags,local.common_data_tags,{'Name': 'my-thing-${var.ENVIRONMENT}-${var.REGION}'})}
+                    # In this case, we expect blocks similar to this:
+                    #  1) ${var.ENVIRONMENT}
+                    #  2) ${var.REGION}
+                    #  3) ${merge(local.common_tags,local.common_data_tags,{'Name': 'my-thing-${var.ENVIRONMENT}-${var.REGION}'})}
+                    # If either of the first two are replaced, we can still process the outer eval block
+                    # if the substitutions made to the earlier vars are also made to the later. That allows
+                    # knowing what the string should really look like so substitutions can be made properly.
+                    # If this proves not to work well, the other option is to abort the later (because
+                    # the full string isn't found in the value anymore) and come back to it on another
+                    # processor loop. This works... but requires another processor loop.
+                    # (If you're thinking we should make a DAG and do this properly... you're probably right.)
+                    prev_matches: List[Tuple[str, str]] = []  # original value -> replaced
+                    for match in find_var_blocks(value):
+                        # Update what's expected in the match, see comment above
+                        for prev_match in prev_matches:
+                            match.replace(prev_match[0], str(prev_match[1]))
 
-                    for match in _find_var_blocks(value):
                         var_base = match.var_only
 
                         # Expressions such as (from variable definition):
@@ -321,7 +340,8 @@ class Parser:
                         #    "type = ${string}"
                         if var_base in _SIMPLE_TYPES and match.full_str == value:
                             altered_value = var_base
-                            had_pattern_match = True
+                            had_var_block_match = True
+                            prev_matches.append((match.full_str, var_base))
                         else:
                             replaced = _handle_single_var_pattern(var_base, var_value_and_file_map,
                                                                   locals_values, resource_list,
@@ -329,13 +349,14 @@ class Parser:
                                                                   eval_map_by_var_name,
                                                                   new_context, value, root_directory)
                             if replaced != var_base:
-                                if match.full_str == value:
+                                if match.full_str == altered_value:
                                     altered_value = replaced
                                 else:
                                     altered_value = altered_value.replace(match.full_str, str(replaced))
-                                had_pattern_match = True
+                                prev_matches.append((match.full_str, replaced))
+                                had_var_block_match = True
 
-                    if not had_pattern_match:
+                    if not had_var_block_match:
                         # tomap is annoying because the curly braces in the string break the regex. Rather than
                         # coming up with something that's significantly more complex, we'll special case this
                         # check. Only do this when there wasn't a pattern match to make sure there are no
@@ -440,7 +461,8 @@ class Parser:
 
                     # Special handling for local sources to make sure we aren't double-parsing
                     if source.startswith("./") or source.startswith("../"):
-                        source = os.path.normpath(os.path.join(os.path.dirname(_remove_module_dependency_in_path(file)), source))
+                        source = os.path.normpath(
+                            os.path.join(os.path.dirname(_remove_module_dependency_in_path(file)), source))
 
                     version = module_call_data.get("version", "latest")
                     if version and isinstance(version, list):
@@ -456,10 +478,14 @@ class Parser:
 
                             if not dir_filter(os.path.abspath(content.path())):
                                 continue
-                            self._internal_dir_load(directory=content.path(), module_loader_registry=module_loader_registry,
-                                                    dir_filter=dir_filter, specified_vars=specified_vars, module_load_context=module_load_context)
+                            self._internal_dir_load(directory=content.path(),
+                                                    module_loader_registry=module_loader_registry,
+                                                    dir_filter=dir_filter, specified_vars=specified_vars,
+                                                    module_load_context=module_load_context)
 
-                            module_definitions = {path: self.out_definitions[path] for path in list(self.out_definitions.keys()) if os.path.dirname(path) == content.path()}
+                            module_definitions = {path: self.out_definitions[path] for path in
+                                                  list(self.out_definitions.keys()) if
+                                                  os.path.dirname(path) == content.path()}
 
                             if not module_definitions:
                                 continue
@@ -514,17 +540,18 @@ def _handle_single_var_pattern(orig_variable: str, var_value_and_file_map: Dict[
                                module_data_retrieval: Callable[[str], Dict[str, Any]],
                                eval_map_by_var_name: Dict[str, EvaluationContext],
                                context, orig_variable_full, root_directory: str) -> Any:
-    if "${" in orig_variable:
-        return orig_variable
+    ternary_info = _is_ternary(orig_variable)
+    if ternary_info:
+        return _process_ternary(orig_variable, ternary_info[0], ternary_info[1])
 
-    elif orig_variable.startswith("module."):
+    if orig_variable.startswith("module."):
         if not module_list:
             return orig_variable
 
         # Reference to module outputs, example: 'module.bucket.bucket_name'
         ref_tokens = orig_variable.split(".")
         if len(ref_tokens) != 3:
-            return orig_variable        # fail safe, can the length ever be something other than 3?
+            return orig_variable  # fail safe, can the length ever be something other than 3?
 
         try:
             ref_list = jmespath.search(f"[].{ref_tokens[1]}.{RESOLVED_MODULE_ENTRY_NAME}[]", module_list)
@@ -555,7 +582,9 @@ def _handle_single_var_pattern(orig_variable: str, var_value_and_file_map: Dict[
 
     elif orig_variable.startswith("var."):
         var_name = orig_variable[4:]
-        var_value_and_file = _handle_indexing(var_name, lambda r: var_value_and_file_map.get(r))
+        var_value_and_file = _handle_indexing(var_name,
+                                              lambda r: var_value_and_file_map.get(r),
+                                              value_is_a_tuple=True)
         if var_value_and_file is not None:
             var_value, var_file = var_value_and_file
             eval_context = eval_map_by_var_name.get(var_name)
@@ -623,10 +652,10 @@ def _handle_single_var_pattern(orig_variable: str, var_value_and_file_map: Dict[
                     else:
                         return str(int(altered_value))
                 except ValueError:
-                    return orig_variable     # no change
+                    return orig_variable  # no change
     elif orig_variable.startswith("merge(") and orig_variable.endswith(")"):
         altered_value = orig_variable[6:-1]
-        args = _split_merge_args(altered_value)
+        args = split_merge_args(altered_value)
         if args is None:
             return orig_variable
         merged_map = {}
@@ -649,7 +678,7 @@ def _handle_single_var_pattern(orig_variable: str, var_value_and_file_map: Dict[
             if isinstance(value, dict):
                 merged_map.update(value)
             else:
-                return orig_variable            # don't know what this is, blow out
+                return orig_variable  # don't know what this is, blow out
         return merged_map
     # TODO - format() support, still in progress
     # elif orig_variable.startswith("format(") and orig_variable.endswith(")"):
@@ -667,29 +696,57 @@ def _handle_single_var_pattern(orig_variable: str, var_value_and_file_map: Dict[
             if result is not None:
                 return result
 
-    return orig_variable        # fall back to no change
+    return orig_variable  # fall back to no change
 
 
-def _handle_indexing(reference: str, data_source: Callable[[str], Optional[Any]]) -> Optional[Any]:
+def _handle_indexing(reference: str,
+                     data_source: Callable[[str], Optional[Any]],
+                     value_is_a_tuple: bool = False) -> Optional[Any]:
+    """
+
+    :param reference:           Full reference with the variable (ex: "my_list[0]")
+    :param data_source:         Data source for retrieving the variable value. Provided the variable name
+                                (ex: "my_list"), the value should be returned, if available.
+    :param value_is_a_tuple:    Indicates whether the returned value will be a tuple with the value as
+                                item 0 and the source location as item 1. This is returned for some data
+                                sources and not for others. When true, the returned value will also be a
+                                Tuple, if non-None.
+    :return:
+    """
     if reference.endswith("]") and "[" in reference:
         base_ref = reference[:reference.rindex("[")]
-        value = data_source(base_ref)
         reference_val = reference[reference.rindex("[") + 1: -1]
+
+        value = data_source(base_ref)
+        if value is None:
+            return None
+
+        if value_is_a_tuple:
+            value_tuple = value
+            value = value_tuple[0]
+
         if isinstance(value, dict):
-            return value.get(reference_val)
+            if value_is_a_tuple:
+                return value.get(reference_val), value_tuple[1]
+            else:
+                return value.get(reference_val)
         elif isinstance(value, list):
             try:
-                return value[int(reference_val)]
+                if value_is_a_tuple:
+                    return value[int(reference_val)], value_tuple[1]
+                else:
+                    return value[int(reference_val)]
             except ValueError as e:
                 # TODO: handle count.index correctly
                 logging.debug(f'Failed to parse index int out of {reference_val}')
                 logging.debug(e, stack_info=True)
-                return
+                return None
     else:
         return data_source(reference)
 
 
-def _load_or_die_quietly(file: os.PathLike, parsing_errors: Dict) -> Optional[Mapping]:
+def _load_or_die_quietly(file: os.PathLike, parsing_errors: Dict,
+                         clean_definitions: bool = True) -> Optional[Mapping]:
     """
 Load JSON or HCL, depending on filename.
     :return: None if the file can't be loaded
@@ -701,18 +758,43 @@ Load JSON or HCL, depending on filename.
     try:
         with open(file, "r") as f:
             if file_name.endswith(".json"):
-                return _clean_bad_definitions(json.load(f))
+                return json.load(f)
             else:
-                return _clean_bad_definitions(hcl2.load(f))
+                raw_data = hcl2.load(f)
+                non_malformed_definitions = _validate_malformed_definitions(raw_data)
+                if clean_definitions:
+                    return _clean_bad_definitions(non_malformed_definitions)
+                else:
+                    return non_malformed_definitions
     except Exception as e:
         LOGGER.debug(f'failed while parsing file {file}', exc_info=e)
         parsing_errors[file_path] = e
         return None
 
 
+def _is_valid_block(block):
+    if not isinstance(block, dict):
+        return True
+    entity_name, _ = next(iter(block.items()))
+    if re.fullmatch(r'[^\W0-9][\w-]*', entity_name):
+        return True
+    return False
+
+
+def _validate_malformed_definitions(raw_data):
+    raw_data_cleaned = copy.deepcopy(raw_data)
+    for block_type, blocks in raw_data.items():
+        raw_data_cleaned[block_type] = [block for block in blocks if _is_valid_block(block)]
+
+    return raw_data_cleaned
+
+
 def _clean_bad_definitions(tf_definition_list):
     return {
-        block_type: list(filter(lambda definition_list: block_type == 'locals' or len(definition_list.keys()) == 1, tf_definition_list[block_type]))
+        block_type: list(filter(lambda definition_list: block_type == 'locals' or
+                                                        not isinstance(definition_list, dict)
+                                                        or len(definition_list.keys()) == 1,
+                                tf_definition_list[block_type]))
         for block_type in tf_definition_list.keys()
     }
 
@@ -720,7 +802,7 @@ def _clean_bad_definitions(tf_definition_list):
 def _eval_string(value: str) -> Optional[Any]:
     try:
         value_string = value.replace("'", '"')
-        parsed = hcl2.loads(f'eval = {value_string}\n')      # NOTE: newline is needed
+        parsed = hcl2.loads(f'eval = {value_string}\n')  # NOTE: newline is needed
         return parsed["eval"][0]
     except Exception:
         return None
@@ -760,153 +842,41 @@ def _remove_module_dependency_in_path(path):
     return path
 
 
-def _split_merge_args(value: str) -> Optional[List[str]]:
+def _is_ternary(value: str) -> Optional[Tuple[int, int]]:
     """
-    Split arguments of a merge function. For example, "merge(local.one, local.two)" would
-    call this function with a value of "local.one, local.two" which would return
-    ["local.one", "local.two"]. If the value cannot be unpacked, None will be returned.
+    Determines whether or not the given string is *probably* a ternary operation
+    :return:        If the expression does represent a possibly-processable ternary expression, a tuple
+                    containing the index of the question mark and colon will be returned.
     """
     if not value:
         return None
-
-    # There are a number of splitting scenarios depending on whether variables or
-    # direct maps are used:
-    #           merge({tag1="foo"},{tag2="bar"})
-    #           merge({tag1="foo"},local.some_tags)
-    #           merge(local.some_tags,{tag2="bar"})
-    #           merge(local.some_tags,local.some_other_tags)
-    # Also, the number of arguments can vary, things can be nested, strings are evil...
-    # See tests/terraform/test_parser_internals.py for many examples.
-
-    to_return = []
-    current_arg_buffer = ""
-    processing_str_escape = False
-    inside_collection_stack = []        # newest at position 0, contains the terminator for the collection
-    for c in value:
-        if c == "," and not inside_collection_stack:
-            current_arg_buffer = current_arg_buffer.strip()
-            # Note: can get a zero-length buffer when there's a double comman. This can
-            #       happen with multi-line args (see parser_internals test)
-            if len(current_arg_buffer) != 0:
-                to_return.append(current_arg_buffer)
-            current_arg_buffer = ""
-        else:
-            current_arg_buffer += c
-
-        processing_str_escape = _str_parser_loop_collection_helper(c,
-                                                                   inside_collection_stack,
-                                                                   processing_str_escape)
-
-    current_arg_buffer = current_arg_buffer.strip()
-    if len(current_arg_buffer) > 0:
-        to_return.append(current_arg_buffer)
-
-    if len(to_return) == 0:
+    question_index = value.find("?")
+    if question_index < 1 or value.count("?") > 1:
         return None
-    return to_return
+    colon_index = value.find(":")
+    if colon_index < question_index or value.count(":") > 1:
+        return None
+    return question_index, colon_index
 
 
-@dataclass
-class VarBlockMatch:
-    full_str: str       # Example: ${local.foo}
-    var_only: str       # Example: local.fop
+def _process_ternary(value: str, question_index: int, colon_index: int) -> str:
+    condition = value[:question_index].strip()
+
+    # Fast & easy case is simple boolean
+    condition_lower = condition.lower()
+    if condition_lower == "true":
+        return _to_native_value(value[question_index + 1: colon_index].strip())
+    elif condition_lower == "false":
+        return _to_native_value(value[colon_index + 1:].strip())
+
+    # Otherwise, this isn't evaluated enough
+    return value
 
 
-def _find_var_blocks(value: str) -> List[VarBlockMatch]:
-    """
-    Find and return all the var blocks within a given string.
-    """
-
-    # Note: This used to be implemented with a regex: r'\${([^{}]+?)}')
-    #       That found ${...} without a {} inside. However, this caused issues with things containing maps
-    #       which needed to be processed.
-
-    to_return: List[VarBlockMatch] = []
-    eval_buffer = ""
-    in_eval = False
-    preceding_dollar = False
-    processing_str_escape = False
-    inside_collection_stack: List[str] = []        # newest at position 0, contains terminator for collection
-    for c in value:
-        if c == "$":
-            if preceding_dollar:        # ignore double $
-                preceding_dollar = False
-                continue
-            preceding_dollar = True
-        elif c == "{" and preceding_dollar:
-            # NOTE: An eval block can start within another eval block, in which case we drop the old
-            #       stuff and process this one.
-            in_eval = True
-            eval_buffer = ""                    # reset buffer
-            inside_collection_stack.clear()     # reset stack
-            processing_str_escape = False
-            preceding_dollar = False
-            continue
-        else:
-            preceding_dollar = False
-
-        if not in_eval:
-            continue
-
-        if c == "}" and not inside_collection_stack:
-            eval_buffer = eval_buffer.strip()
-            if len(eval_buffer) == 0:
-                # Something went wrong because we have an empty arg. Blow out.
-                return []
-            to_return.append(VarBlockMatch("${" + eval_buffer + "}", eval_buffer))
-            eval_buffer = ""
-            in_eval = False
-            continue
-        else:
-            eval_buffer += c
-
-        processing_str_escape = _str_parser_loop_collection_helper(c, inside_collection_stack,
-                                                                   processing_str_escape)
-
-    return to_return
-
-
-def _str_parser_loop_collection_helper(c: str, inside_collection_stack: List[str],
-                                       processing_str_escape: bool) -> bool:
-    """
-    This function handles dealing with tracking when a char-by-char state loop is inside a
-    "collection" (map, array index, method args, string).
-
-    :param c:       Active character
-    :param inside_collection_stack:     Stack of terminators for collections. This will be modified by
-                                        this function. The active terminator will be at position 0.
-
-
-    :return: value to set for `processing_str_escape`
-    """
-    inside_a_string = False
-    if inside_collection_stack:
-        terminator = inside_collection_stack[0]
-
-        if terminator == '"' or terminator == "'":
-            if processing_str_escape:
-                processing_str_escape = False
-                return processing_str_escape
-            elif c == "\\":
-                processing_str_escape = True
-                return processing_str_escape
-            else:
-                inside_a_string = True
-
-        if c == terminator:
-            del inside_collection_stack[0]
-            return processing_str_escape
-
-    if not inside_a_string:
-        if c == '"':
-            inside_collection_stack.insert(0, '"')
-        elif c == "'":
-            inside_collection_stack.insert(0, "'")
-        elif c == "{":
-            inside_collection_stack.insert(0, "}")
-        elif c == "[":
-            inside_collection_stack.insert(0, "]")
-        elif c == "(":
-            inside_collection_stack.insert(0, ")")
-
-    return processing_str_escape
+def _safe_index(sequence_hopefully, index) -> Optional[Any]:
+    try:
+        return sequence_hopefully[index]
+    except IndexError as e:
+        logging.debug(f'Failed to parse index int ({index}) out of {sequence_hopefully}')
+        logging.debug(e, stack_info=True)
+        return None
