@@ -20,6 +20,8 @@ from checkov.terraform.evaluation.base_variable_evaluation import BaseVariableEv
 from checkov.terraform.parser import Parser
 
 # Allow the evaluation of empty variables
+from checkov.terraform.tag_providers import get_resource_tags
+
 dpath.options.ALLOW_EMPTY_STRING_KEYS = True
 
 LOG_LEVEL = os.getenv('LOG_LEVEL', 'WARNING').upper()
@@ -75,7 +77,7 @@ class Runner(BaseRunner):
                         continue
                     self.check_tf_definition(report, root_folder, runner_filter, collect_skip_comments)
 
-        report.add_parsing_errors(parsing_errors)
+        report.add_parsing_errors(parsing_errors.keys())
 
         return report
 
@@ -141,12 +143,16 @@ class Runner(BaseRunner):
                 entity_evaluations = BaseVariableEvaluation.reduce_entity_evaluations(variables_evaluations,
                                                                                       entity_context_path)
             results = registry.scan(scanned_file, entity, skipped_checks, runner_filter)
+            absolut_scanned_file_path = self._strip_module_referrer(file_path=full_file_path)
+            # This duplicates a call at the start of scan, but adding this here seems better than kludging with some tuple return type
+            (entity_type, _, entity_config) = registry.extract_entity_details(entity)
+            tags = get_resource_tags(entity_type, entity_config)
             for check, check_result in results.items():
                 record = Record(check_id=check.id, check_name=check.name, check_result=check_result,
                                 code_block=entity_code_lines, file_path=scanned_file,
                                 file_line_range=entity_lines_range,
                                 resource=entity_id, evaluations=entity_evaluations,
-                                check_class=check.__class__.__module__)
+                                check_class=check.__class__.__module__, file_abs_path=absolut_scanned_file_path, entity_tags=tags)
                 report.add_record(record=record)
 
     @staticmethod
